.. archive-pdf-tools documentation master file, created by
   sphinx-quickstart on Sun Mar 21 16:00:40 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to archive-pdf-tools's documentation!
=============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Tools Usage
-----------

TODO:

* recode_pdf
* mrcview
* pdfimages

Testing tools
-------------


Library usage
-------------


Components
----------

.. toctree::
   :maxdepth: 2
   :caption: Sections:

   mrc.rst
   pagenumbers.rst
   pdfrenderer.rst
   recode.rst
   scandata.rst
   cython.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
